@@ -25,23 +25,22 @@ Example::
 from __future__ import annotations
 
 import builtins
-import sys
-import warnings
-import os
-import fnmatch
-import glob
-import shutil
-import hashlib
-import errno
-import tempfile
-import functools
-import re
 import contextlib
+import datetime
+import errno
+import fnmatch
+import functools
+import glob
+import hashlib
 import importlib
 import itertools
-import datetime
+import os
+import re
+import shutil
+import sys
+import tempfile
+import warnings
 from numbers import Number
-from typing import Union
 
 with contextlib.suppress(ImportError):
     import win32security
@@ -60,32 +59,27 @@ from io import (
     TextIOWrapper,
 )
 from typing import (
+    IO,
+    TYPE_CHECKING,
     Any,
     BinaryIO,
     Callable,
-    IO,
     Iterator,
-    Optional,
     overload,
 )
 
-from typing import TYPE_CHECKING
-
 if TYPE_CHECKING:
     from _typeshed import (
         OpenBinaryMode,
-        OpenBinaryModeUpdating,
         OpenBinaryModeReading,
+        OpenBinaryModeUpdating,
         OpenBinaryModeWriting,
         OpenTextMode,
     )
     from typing_extensions import Literal
 
-from . import matchers
-from . import masks
-from . import classes
-from .compat.py38 import removesuffix
-
+from . import classes, masks, matchers
+from .compat.py38 import removeprefix, removesuffix
 
 __all__ = ['Path', 'TempDir']
 
@@ -100,7 +94,7 @@ U_NL_END = re.compile(U_NEWLINE.pattern + '$')
 _default_linesep = object()
 
 
-def _make_timestamp_ns(value: Union[Number, datetime.datetime]) -> Number:
+def _make_timestamp_ns(value: Number | datetime.datetime) -> Number:
     timestamp_s = value if isinstance(value, Number) else value.timestamp()
     return int(timestamp_s * 10**9)
 
@@ -203,7 +197,7 @@ class Path(str):
     # --- Special Python methods.
 
     def __repr__(self):
-        return '{}({})'.format(type(self).__name__, super().__repr__())
+        return f'{type(self).__name__}({super().__repr__()})'
 
     # Adding a Path and a string yields a Path.
     def __add__(self, more):
@@ -259,10 +253,18 @@ class Path(str):
     #
     # --- Operations on Path strings.
 
-    def abspath(self):
+    def absolute(self):
         """.. seealso:: :func:`os.path.abspath`"""
         return self._next_class(self.module.abspath(self))
 
+    def abspath(self):
+        warnings.warn(
+            ".abspath is deprecated; use absolute",
+            DeprecationWarning,
+            stacklevel=2,
+        )
+        return self.absolute()
+
     def normcase(self):
         """.. seealso:: :func:`os.path.normcase`"""
         return self._next_class(self.module.normcase(self))
@@ -325,7 +327,7 @@ class Path(str):
         return suffix
 
     @property
-    def ext(self):
+    def ext(self):  # pragma: no cover
         warnings.warn(
             ".ext is deprecated; use suffix",
             DeprecationWarning,
@@ -498,10 +500,10 @@ class Path(str):
 
         If there is no relative path from `self` to `dest`, for example if
         they reside on different drives in Windows, then this returns
-        ``dest.abspath()``.
+        ``dest.absolute()``.
         """
-        origin = self.abspath()
-        dest = self._next_class(dest).abspath()
+        origin = self.absolute()
+        dest = self._next_class(dest).absolute()
 
         orig_list = origin.normcase().splitall()
         # Don't normcase dest!  We want to preserve the case.
@@ -689,11 +691,11 @@ class Path(str):
         self,
         mode: OpenTextMode = ...,
         buffering: int = ...,
-        encoding: Optional[str] = ...,
-        errors: Optional[str] = ...,
-        newline: Optional[str] = ...,
+        encoding: str | None = ...,
+        errors: str | None = ...,
+        newline: str | None = ...,
         closefd: bool = ...,
-        opener: Optional[Callable[[str, int], int]] = ...,
+        opener: Callable[[str, int], int] | None = ...,
     ) -> TextIOWrapper: ...
 
     @overload
@@ -701,9 +703,9 @@ class Path(str):
         self,
         mode: OpenBinaryMode,
         buffering: Literal[0],
-        encoding: Optional[str] = ...,
-        errors: Optional[str] = ...,
-        newline: Optional[str] = ...,
+        encoding: str | None = ...,
+        errors: str | None = ...,
+        newline: str | None = ...,
         closefd: bool = ...,
         opener: Callable[[str, int], int] = ...,
     ) -> FileIO: ...
@@ -713,9 +715,9 @@ class Path(str):
         self,
         mode: OpenBinaryModeUpdating,
         buffering: Literal[-1, 1] = ...,
-        encoding: Optional[str] = ...,
-        errors: Optional[str] = ...,
-        newline: Optional[str] = ...,
+        encoding: str | None = ...,
+        errors: str | None = ...,
+        newline: str | None = ...,
         closefd: bool = ...,
         opener: Callable[[str, int], int] = ...,
     ) -> BufferedRandom: ...
@@ -725,9 +727,9 @@ class Path(str):
         self,
         mode: OpenBinaryModeReading,
         buffering: Literal[-1, 1] = ...,
-        encoding: Optional[str] = ...,
-        errors: Optional[str] = ...,
-        newline: Optional[str] = ...,
+        encoding: str | None = ...,
+        errors: str | None = ...,
+        newline: str | None = ...,
         closefd: bool = ...,
         opener: Callable[[str, int], int] = ...,
     ) -> BufferedReader: ...
@@ -737,9 +739,9 @@ class Path(str):
         self,
         mode: OpenBinaryModeWriting,
         buffering: Literal[-1, 1] = ...,
-        encoding: Optional[str] = ...,
-        errors: Optional[str] = ...,
-        newline: Optional[str] = ...,
+        encoding: str | None = ...,
+        errors: str | None = ...,
+        newline: str | None = ...,
         closefd: bool = ...,
         opener: Callable[[str, int], int] = ...,
     ) -> BufferedWriter: ...
@@ -749,9 +751,9 @@ class Path(str):
         self,
         mode: OpenBinaryMode,
         buffering: int,
-        encoding: Optional[str] = ...,
-        errors: Optional[str] = ...,
-        newline: Optional[str] = ...,
+        encoding: str | None = ...,
+        errors: str | None = ...,
+        newline: str | None = ...,
         closefd: bool = ...,
         opener: Callable[[str, int], int] = ...,
     ) -> BinaryIO: ...
@@ -761,9 +763,9 @@ class Path(str):
         self,
         mode: str,
         buffering: int = ...,
-        encoding: Optional[str] = ...,
-        errors: Optional[str] = ...,
-        newline: Optional[str] = ...,
+        encoding: str | None = ...,
+        errors: str | None = ...,
+        newline: str | None = ...,
         closefd: bool = ...,
         opener: Callable[[str, int], int] = ...,
     ) -> IO[Any]: ...
@@ -787,11 +789,11 @@ class Path(str):
         size: int,
         mode: OpenTextMode = ...,
         buffering: int = ...,
-        encoding: Optional[str] = ...,
-        errors: Optional[str] = ...,
-        newline: Optional[str] = ...,
+        encoding: str | None = ...,
+        errors: str | None = ...,
+        newline: str | None = ...,
         closefd: bool = ...,
-        opener: Optional[Callable[[str, int], int]] = ...,
+        opener: Callable[[str, int], int] | None = ...,
     ) -> Iterator[str]: ...
 
     @overload
@@ -800,11 +802,11 @@ class Path(str):
         size: int,
         mode: OpenBinaryMode,
         buffering: int = ...,
-        encoding: Optional[str] = ...,
-        errors: Optional[str] = ...,
-        newline: Optional[str] = ...,
+        encoding: str | None = ...,
+        errors: str | None = ...,
+        newline: str | None = ...,
         closefd: bool = ...,
-        opener: Optional[Callable[[str, int], int]] = ...,
+        opener: Callable[[str, int], int] | None = ...,
     ) -> Iterator[builtins.bytes]: ...
 
     @overload
@@ -813,12 +815,12 @@ class Path(str):
         size: int,
         mode: str,
         buffering: int = ...,
-        encoding: Optional[str] = ...,
-        errors: Optional[str] = ...,
-        newline: Optional[str] = ...,
+        encoding: str | None = ...,
+        errors: str | None = ...,
+        newline: str | None = ...,
         closefd: bool = ...,
-        opener: Optional[Callable[[str, int], int]] = ...,
-    ) -> Iterator[Union[str, builtins.bytes]]: ...
+        opener: Callable[[str, int], int] | None = ...,
+    ) -> Iterator[str | builtins.bytes]: ...
 
     def chunks(self, size, *args, **kwargs):
         """Returns a generator yielding chunks of the file, so it can
@@ -877,9 +879,9 @@ class Path(str):
     def write_text(
         self,
         text: str,
-        encoding: Optional[str] = ...,
+        encoding: str | None = ...,
         errors: str = ...,
-        linesep: Optional[str] = ...,
+        linesep: str | None = ...,
         append: bool = ...,
     ) -> None: ...
 
@@ -889,7 +891,7 @@ class Path(str):
         text: builtins.bytes,
         encoding: None = ...,
         errors: str = ...,
-        linesep: Optional[str] = ...,
+        linesep: str | None = ...,
         append: bool = ...,
     ) -> None: ...
 
@@ -1096,7 +1098,7 @@ class Path(str):
         """.. seealso:: :func:`os.path.exists`"""
         return self.module.exists(self)
 
-    def isdir(self):
+    def isdir(self):  # pragma: no cover
         warnings.warn(
             "isdir is deprecated; use is_dir",
             DeprecationWarning,
@@ -1108,7 +1110,7 @@ class Path(str):
         """.. seealso:: :func:`os.path.isdir`"""
         return self.module.isdir(self)
 
-    def isfile(self):
+    def isfile(self):  # pragma: no cover
         warnings.warn(
             "isfile is deprecated; use is_file",
             DeprecationWarning,
@@ -1498,7 +1500,7 @@ class Path(str):
 
         .. seealso:: :meth:`readlinkabs`, :func:`os.readlink`
         """
-        return self._next_class(os.readlink(self))
+        return self._next_class(removeprefix(os.readlink(self), '\\\\?\\'))
 
     def readlinkabs(self):
         """Return the path to which this symbolic link points.
@@ -1508,7 +1510,7 @@ class Path(str):
         .. seealso:: :meth:`readlink`, :func:`os.readlink`
         """
         p = self.readlink()
-        return p if p.isabs() else (self.parent / p).abspath()
+        return p if p.isabs() else (self.parent / p).absolute()
 
     # High-level functions from shutil
     # These functions will be bound to the instance such that
@@ -1873,7 +1875,7 @@ class Handlers:
         raise
 
     def warn(msg):
-        warnings.warn(msg, TreeWalkWarning)
+        warnings.warn(msg, TreeWalkWarning, stacklevel=2)
 
     def ignore(msg):
         pass
